#include "certificatetablemodel.h"

CertificateTabelModel::CertificateTabelModel(QObject *parent)
    : QAbstractTableModel(parent)
{
    header.append("");
    header.append(tr("CN"));
    header.append(tr("issued  on"));
    header.append(tr("expires on"));
    header.append(tr("Fingerprint"));

}

void CertificateTabelModel::addCertificate(const Certificate& certificate)
{
    beginInsertRows(QModelIndex(), rowCount(), rowCount());
    certificates.append(certificate);
    endInsertRows();
}

QVariant CertificateTabelModel::data(const QModelIndex &index,
        int role) const
{
    if (index.row() > certificates.size() || index.row() < 0) {
        return QVariant();
    }

    if (role == Qt::DisplayRole) {
        Certificate cert = certificates.at(index.row());
        QVariant ret;
        switch(index.column()) {
        case 0: ret = cert.isInstallCert(); break;
        case 1: ret = cert.subjectCN(); break;
        case 2: ret = cert.validFrom(); break;
        case 3: ret = cert.validTo(); break;
        case 4: ret = "Fingerprint"; break;
        default: ;
        }
        return ret;
    }

    return QVariant();
}

bool CertificateTabelModel::setData(const QModelIndex &index,
    const QVariant &value, int role)
{
    if (index.row() > certificates.size() || index.row() < 0) {
        return false;
    }

    bool newValue = value.toBool();
    Certificate &cert = certificates[index.row()];
    cert.setInstallCert(newValue);

    emit dataChanged(index, index);

    return true;
}

QVariant CertificateTabelModel::headerData(int section,
        Qt::Orientation orientation, int role) const
{
    if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
        return header.at(section);
    }
    return QVariant();
}

int CertificateTabelModel::rowCount(const QModelIndex&) const
{
    return certificates.size();
}

int CertificateTabelModel::columnCount(const QModelIndex&) const
{
    return header.size();
}

Qt::ItemFlags CertificateTabelModel::flags(const QModelIndex &index) const
{
    if (!index.isValid ())
        return Qt::ItemIsSelectable;

    if (index.column() == 0) {
        return QAbstractTableModel::flags(index) | Qt::ItemIsEditable;
    }

    return QAbstractTableModel::flags(index);
}
